==> mongodb-5.0.30.gh.tar.gz: mongo-r5.0.30/jstests/sharding/all_config_servers_blackholed_from_mongos.js <==
/**
 * Ensures that if the config servers are blackholed from the point of view of MongoS, metadata
 * operations do not get stuck forever.
 *
 * Checking UUID and index consistency involves talking to config servers through mongos, but mongos
 * is blackholed from the config servers in this test.
 */

TestData.skipCheckingUUIDsConsistentAcrossCluster = true;
TestData.skipCheckingIndexesConsistentAcrossCluster = true;
TestData.skipCheckOrphans = true;

(function() {
'use strict';

var st = new ShardingTest({
    shards: 2,
    mongos: 1,
    useBridge: true,
});

var testDB = st.s.getDB('BlackHoleDB');

assert.commandWorked(testDB.adminCommand({enableSharding: 'BlackHoleDB'}));
assert.commandWorked(
    testDB.adminCommand({shardCollection: testDB.ShardedColl.getFullName(), key: {_id: 1}}));

assert.commandWorked(testDB.ShardedColl.insert({a: 1}));

jsTest.log('Making all the config servers appear as a blackhole to mongos');
st._configServers.forEach(function(configSvr) {
    configSvr.discardMessagesFrom(st.s, 1.0);
});

assert.commandWorked(testDB.adminCommand({flushRouterConfig: 1}));

// This shouldn't stall
jsTest.log('Doing read operation on the sharded collection');
assert.throws(function() {
    testDB.ShardedColl.find({}).maxTimeMS(15000).itcount();
});

// This should fail, because the primary is not available
jsTest.log('Doing write operation on a new database and collection');
assert.writeError(
    st.s.getDB('NonExistentDB')
        .TestColl.insert({_id: 0, value: 'This value will never be inserted'}, {maxTimeMS: 15000}));

st.stop();
}());

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/jstests/sharding/all_config_servers_blackholed_from_mongos.js <==
/**
 * Ensures that if the config servers are blackholed from the point of view of MongoS, metadata
 * operations do not get stuck forever.
 *
 * Checking UUID and index consistency involves talking to config servers through mongos, but mongos
 * is blackholed from the config servers in this test.
 * @tags: [
 *   temp_disabled_embedded_router_mongo_bridge,
 * ]
 */

TestData.skipCheckingUUIDsConsistentAcrossCluster = true;
TestData.skipCheckingIndexesConsistentAcrossCluster = true;
TestData.skipCheckOrphans = true;
TestData.skipCheckRoutingTableConsistency = true;
TestData.skipCheckShardFilteringMetadata = true;
TestData.skipCheckMetadataConsistency = true;

var st = new ShardingTest({
    shards: 2,
    mongos: 1,
    useBridge: true,
    bridgeOptions: {verbose: 'vvv'},
});

var testDB = st.s.getDB('BlackHoleDB');

assert.commandWorked(testDB.adminCommand({enableSharding: 'BlackHoleDB'}));
assert.commandWorked(
    testDB.adminCommand({shardCollection: testDB.ShardedColl.getFullName(), key: {_id: 1}}));

assert.commandWorked(testDB.ShardedColl.insert({a: 1}));

jsTest.log('Making all the config servers appear as a blackhole to mongos');
st.forEachConfigServer((configSvr) => {
    configSvr.discardMessagesFrom(st.s, 1.0);
});

assert.commandWorked(testDB.adminCommand({flushRouterConfig: 1}));

// This shouldn't stall
jsTest.log('Doing read operation on the sharded collection');
assert.throws(function() {
    testDB.ShardedColl.find({}).maxTimeMS(15000).itcount();
});

// This should fail, because the primary is not available
jsTest.log('Doing write operation on a new database and collection');
assert.writeError(
    st.s.getDB('NonExistentDB')
        .TestColl.insert({_id: 0, value: 'This value will never be inserted'}, {maxTimeMS: 15000}));

st.stop();
